==> tmaid-2.3.1.tar.gz: tmaid-2.3.1/src/charlist.h <==
/*
    Text maid
    copyright (c) 1998-2003 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
#ifndef __CHARLIST_H__
#define __CHARLIST_H__


#include "tmaid.h"


/******************************************************************************
*                                                                             *
* 饯åȥꥹȥؿ                                    *
*                                                                             *
******************************************************************************/
/*	饯åȤȽꤹ
	charset,饯å
	    RET,TRUE:,FALSE:											*/
gboolean
charlist_is_valid (const gchar *charset);


/*	饯åȤ
	charset,饯å
	    RET,줿饯å									*/
gchar *
charlist_strip (const gchar *charlist);


/*	饯åȤִ
	charlist,饯å
	charsets,ִ륭饯å
	     RET,ִ줿饯å									*/
gchar *
charlist_rename (const gchar *charlist, const gchar *charsets);


/*	饯åȤɲä
	charlist,饯å
	charsets,ɲä륭饯å
	     RET,ɲä줿饯å									*/
gchar *
charlist_append (const gchar *charlist, const gchar *charsets);


/*	饯åȤ
	charlist,饯å
	 charset,륭饯å
	     RET,줿饯å									*/
gchar *
charlist_remove (const gchar *charlist, const gchar *charset);


/*	饯åȤִ
	charlist,ִ륭饯å
	   ft_id,ե륿פID(-1:ɲäʤ)								*/
void
charlist_renewal_all (const gchar *charlist, const gint ft_id);


gchar *
charlist_dialog (gchar *charset);


#endif

==> tmaid-2.3.3.tar.gz: tmaid-2.3.3/src/charlist.h <==
/*
    Text maid
    copyright (c) 1998-2003 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
#ifndef __CHARLIST_H__
#define __CHARLIST_H__


#include "tmaid.h"


/******************************************************************************
*                                                                             *
* 饯åȥꥹȥؿ                                    *
*                                                                             *
******************************************************************************/
/*	饯åȤȽꤹ
	charset,饯å
	    RET,TRUE:,FALSE:											*/
gboolean
charlist_is_valid (const gchar *charset);


/*	饯åȥꥹȤ
	charlist,饯åȥꥹ
	     RET,줿饯åȥꥹ								*/
gchar *
charlist_strip (const gchar *charlist);


/*	饯åȥꥹȤִ
	charlist0,饯åȥꥹ
	charlist1,ִ륭饯åȥꥹ
	     RET,ִ줿饯åȥꥹ								*/
gchar *
charlist_rename (const gchar *charlist0, const gchar *charlist1);


/*	饯åȥꥹȤɲä
	charlist,饯åȥꥹ
	charsets,ɲä륭饯åȥꥹ
	     RET,ɲä줿饯åȥꥹ								*/
gchar *
charlist_append (const gchar *charlist0, const gchar *charlist1);


/*	饯åȤ
	charlist,饯åȥꥹ
	 charset,륭饯å
	     RET,줿饯åȥꥹ								*/
gchar *
charlist_remove (const gchar *charlist, const gchar *charset);


/*	饯åȤִ
	charlist,ִ륭饯å
	   ft_id,ե륿פID(-1:ɲäʤ)								*/
void
charlist_renewal_all (const gchar *charlist, const gint ft_id);


gchar *
charlist_dialog (gchar *charset);


#endif
